# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'MembershipAuthorityArgs',
    'MembershipEndpointArgs',
    'MembershipEndpointGkeClusterArgs',
]

@pulumi.input_type
class MembershipAuthorityArgs:
    def __init__(__self__, *,
                 issuer: pulumi.Input[str]):
        """
        :param pulumi.Input[str] issuer: A JSON Web Token (JWT) issuer URI. `issuer` must start with `https://` and // be a valid
               with length <2000 characters.
        """
        pulumi.set(__self__, "issuer", issuer)

    @property
    @pulumi.getter
    def issuer(self) -> pulumi.Input[str]:
        """
        A JSON Web Token (JWT) issuer URI. `issuer` must start with `https://` and // be a valid
        with length <2000 characters.
        """
        return pulumi.get(self, "issuer")

    @issuer.setter
    def issuer(self, value: pulumi.Input[str]):
        pulumi.set(self, "issuer", value)


@pulumi.input_type
class MembershipEndpointArgs:
    def __init__(__self__, *,
                 gke_cluster: Optional[pulumi.Input['MembershipEndpointGkeClusterArgs']] = None):
        """
        :param pulumi.Input['MembershipEndpointGkeClusterArgs'] gke_cluster: If this Membership is a Kubernetes API server hosted on GKE, this is a self link to its GCP resource.
               Structure is documented below.
        """
        if gke_cluster is not None:
            pulumi.set(__self__, "gke_cluster", gke_cluster)

    @property
    @pulumi.getter(name="gkeCluster")
    def gke_cluster(self) -> Optional[pulumi.Input['MembershipEndpointGkeClusterArgs']]:
        """
        If this Membership is a Kubernetes API server hosted on GKE, this is a self link to its GCP resource.
        Structure is documented below.
        """
        return pulumi.get(self, "gke_cluster")

    @gke_cluster.setter
    def gke_cluster(self, value: Optional[pulumi.Input['MembershipEndpointGkeClusterArgs']]):
        pulumi.set(self, "gke_cluster", value)


@pulumi.input_type
class MembershipEndpointGkeClusterArgs:
    def __init__(__self__, *,
                 resource_link: pulumi.Input[str]):
        pulumi.set(__self__, "resource_link", resource_link)

    @property
    @pulumi.getter(name="resourceLink")
    def resource_link(self) -> pulumi.Input[str]:
        return pulumi.get(self, "resource_link")

    @resource_link.setter
    def resource_link(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_link", value)


