# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .environment import *
from .instance import *
from .instance_iam_binding import *
from .instance_iam_member import *
from .instance_iam_policy import *
from .location import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "gcp:notebooks/environment:Environment":
                return Environment(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:notebooks/instance:Instance":
                return Instance(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:notebooks/instanceIamBinding:InstanceIamBinding":
                return InstanceIamBinding(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:notebooks/instanceIamMember:InstanceIamMember":
                return InstanceIamMember(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:notebooks/instanceIamPolicy:InstanceIamPolicy":
                return InstanceIamPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:notebooks/location:Location":
                return Location(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("gcp", "notebooks/environment", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "notebooks/instance", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "notebooks/instanceIamBinding", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "notebooks/instanceIamMember", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "notebooks/instanceIamPolicy", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "notebooks/location", _module_instance)

_register_module()
