# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .default_supported_idp_config import *
from .inbound_saml_config import *
from .oauth_idp_config import *
from .tenant import *
from .tenant_default_supported_idp_config import *
from .tenant_inbound_saml_config import *
from .tenant_oauth_idp_config import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "gcp:identityplatform/defaultSupportedIdpConfig:DefaultSupportedIdpConfig":
                return DefaultSupportedIdpConfig(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:identityplatform/inboundSamlConfig:InboundSamlConfig":
                return InboundSamlConfig(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:identityplatform/oauthIdpConfig:OauthIdpConfig":
                return OauthIdpConfig(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:identityplatform/tenant:Tenant":
                return Tenant(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:identityplatform/tenantDefaultSupportedIdpConfig:TenantDefaultSupportedIdpConfig":
                return TenantDefaultSupportedIdpConfig(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:identityplatform/tenantInboundSamlConfig:TenantInboundSamlConfig":
                return TenantInboundSamlConfig(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:identityplatform/tenantOauthIdpConfig:TenantOauthIdpConfig":
                return TenantOauthIdpConfig(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("gcp", "identityplatform/defaultSupportedIdpConfig", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "identityplatform/inboundSamlConfig", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "identityplatform/oauthIdpConfig", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "identityplatform/tenant", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "identityplatform/tenantDefaultSupportedIdpConfig", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "identityplatform/tenantInboundSamlConfig", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "identityplatform/tenantOauthIdpConfig", _module_instance)

_register_module()
